@@ -1,5 +1,8 @@
 from dataclasses import dataclass
 from typing import List, Optional
+from urllib.parse import urlencode
+
+from requests.models import RequestEncodingMixin
 from etsy_apiv3.utils import EtsySession, Response
 from etsy_apiv3.models import (
     Translation, Product, Offering, Listing,
@@ -331,4 +334,35 @@ class ListingResource:
         json = await self.session.async_request(endpoint, params={"includes":includes})
         return Listing(**json)
     
+    async def afind_all_active_listings(self, limit=25, offset=0, keywords="", sort_on="created", sort_order="desc", min_price=None, max_price=None, taxonomy_id=None, shop_location="United States"):
+        """
+        Find All Active Listings By Keywords, Min price, Max Price Or Shop Location
+
+        Args:
+            limit (int, optional): Result Limit. Defaults to 25, Max 100.
+            offset (int, optional): Result Offset. Defaults to 0.
+            keywords (str, optional): Keywords For Active Listings. Defaults to "".
+            sort_on (str, optional): Sort By Result. Defaults to "created".
+            sort_order (str, optional): Sort By Order. Defaults to "desc".
+            min_price (_type_, optional): Min Price. Defaults to None.
+            max_price (_type_, optional): Max Price. Defaults to None.
+            taxonomy_id (_type_, optional): Taxonomy Id. Defaults to None.
+            shop_location (_type_, optional): Shop Location. Defaults to US.
+
+        Returns:
+            Response[Listing]: List of Listing Items
+        """
+        
+        endpoint = f"listings/active"
+        params = {
+            "limit":limit, "offset":offset, "keywords":keywords, "sort_on":sort_on,
+            "sort_order":sort_order, "min_price":min_price, "max_price":max_price,
+            "taxonomy_id":taxonomy_id, "shop_location":shop_location
+        }
+        
+        
+        
+        json = await self.session.async_request(endpoint, params=RequestEncodingMixin._encode_params(params))
+
+        return Response[Listing](**json)
     
\ No newline at end of file
